#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

"""Language data definitions.

This is an automatically generated file, see scripts/generate-language-data

Do not edit, please adjust language definitions in following repository:
https://github.com/WeblateOrg/language-data
"""
# pylint: disable=line-too-long,too-many-lines


# Known language codes
LANGUAGES = {
    "aa",
    "aar",
    "ab",
    "abk",
    "ace",
    "ach",
    "ada",
    "ady",
    "ae",
    "af",
    "afh",
    "afr",
    "aii",
    "ain",
    "ak",
    "aka",
    "akk",
    "alb",
    "ale",
    "alt",
    "am",
    "amh",
    "an",
    "ang",
    "ang@latin",
    "anp",
    "ar",
    "ar_ar",
    "ar_bh",
    "ar_dz",
    "ar_eg",
    "ar_kw",
    "ar_ly",
    "ar_ma",
    "ar_sa",
    "ar_xb",
    "ar_ye",
    "ara",
    "arc",
    "arg",
    "arm",
    "arn",
    "arp",
    "ars",
    "arw",
    "ary",
    "as",
    "asa",
    "asm",
    "ast",
    "av",
    "ava",
    "ave",
    "awa",
    "ay",
    "ayc",
    "aym",
    "az",
    "az_ir",
    "azb",
    "aze",
    "ba",
    "ba_ck",
    "bak",
    "bal",
    "bam",
    "ban",
    "baq",
    "bar",
    "bas",
    "base",
    "bd",
    "be",
    "be@latin",
    "be_latn",
    "be_rby",
    "bej",
    "bel",
    "bem",
    "ben",
    "ber",
    "bez",
    "bg",
    "bgr",
    "bh",
    "bho",
    "bi",
    "bih",
    "bik",
    "bin",
    "bis",
    "bla",
    "bm",
    "bn",
    "bn_bd",
    "bn_in",
    "bnt",
    "bo",
    "bo_cn",
    "bod",
    "bos",
    "br",
    "bra",
    "braz_por",
    "bre",
    "brx",
    "bs",
    "bs_cyrl",
    "bs_latn",
    "bs_latn_ba",
    "bua",
    "bug",
    "bul",
    "bur",
    "by",
    "byn",
    "ca",
    "ca@valencia",
    "ca_ad",
    "ca_es@valencia",
    "ca_ps",
    "ca_valencia",
    "ca_xv",
    "cad",
    "cak",
    "car",
    "cat",
    "ce",
    "ceb",
    "ces",
    "cgg",
    "ch",
    "cha",
    "chb",
    "che",
    "chg",
    "chi",
    "chinese",
    "chinese_chs",
    "chinese_zh",
    "chk",
    "chm",
    "chn",
    "cho",
    "chp",
    "chr",
    "chs",
    "cht",
    "chu",
    "chv",
    "chy",
    "ckb",
    "ckb_iq",
    "ckb_ir",
    "cmn",
    "cn",
    "co",
    "cop",
    "cor",
    "cos",
    "cpe",
    "cpf",
    "cpp",
    "cr",
    "cre",
    "crh",
    "crp",
    "cs",
    "csb",
    "csy",
    "cu",
    "cv",
    "cy",
    "cym",
    "cz",
    "cze",
    "da",
    "dak",
    "dan",
    "dar",
    "de",
    "de@formal",
    "de@informal",
    "de_1901",
    "de_at",
    "de_ch",
    "de_de_x_formal",
    "de_de_x_informal",
    "de_fo",
    "de_form",
    "de_lu",
    "del",
    "den",
    "des",
    "deu",
    "dgo",
    "dgr",
    "din",
    "div",
    "dk",
    "doi",
    "dsb",
    "dua",
    "dum",
    "dut",
    "dutch_be",
    "dv",
    "dyu",
    "dz",
    "dzo",
    "ee",
    "efi",
    "eg",
    "egy",
    "eka",
    "el",
    "ell",
    "elx",
    "en",
    "en_au",
    "en_ca",
    "en_devel",
    "en_en",
    "en_gb",
    "en_ie",
    "en_in",
    "en_nz",
    "en_ph",
    "en_us",
    "en_xa",
    "en_za",
    "ena",
    "eng",
    "english_uk",
    "enm",
    "enp",
    "enu",
    "eo",
    "epo",
    "es",
    "es_419",
    "es_ar",
    "es_bo",
    "es_cl",
    "es_co",
    "es_cr",
    "es_do",
    "es_ec",
    "es_eu",
    "es_mx",
    "es_ni",
    "es_pa",
    "es_pe",
    "es_pr",
    "es_sv",
    "es_us",
    "es_uy",
    "es_ve",
    "esp",
    "est",
    "et",
    "eu",
    "eus",
    "ewe",
    "ewo",
    "ext",
    "fa",
    "fa_af",
    "fan",
    "fao",
    "fas",
    "fat",
    "ff",
    "fi",
    "fij",
    "fil",
    "fin",
    "fj",
    "flemish",
    "fo",
    "fon",
    "fr",
    "fr@formal",
    "fr@informal",
    "fr_ag",
    "fr_be",
    "fr_ca",
    "fr_ch",
    "fr_fo",
    "fr_form",
    "fr_fr_x_formal",
    "fr_fr_x_informal",
    "fr_lu",
    "fr_sn",
    "fra",
    "frb",
    "frc",
    "fre",
    "frm",
    "fro",
    "frp",
    "frr",
    "frs",
    "fry",
    "ful",
    "fur",
    "fy",
    "ga",
    "gaa",
    "gae",
    "gay",
    "gba",
    "gbm",
    "gd",
    "geo",
    "ger",
    "gez",
    "gil",
    "gl",
    "gla",
    "gle",
    "glg",
    "glk",
    "glv",
    "gmh",
    "gn",
    "goh",
    "gon",
    "gor",
    "got",
    "gr",
    "grb",
    "grc",
    "gre",
    "grn",
    "gsw",
    "gu",
    "gu_in",
    "gug",
    "guj",
    "gun",
    "guw",
    "gv",
    "gwi",
    "ha",
    "hai",
    "hat",
    "hau",
    "haw",
    "hbs",
    "he",
    "he_il",
    "heb",
    "her",
    "hi",
    "hi_latn",
    "hil",
    "hin",
    "hit",
    "hmn",
    "hmo",
    "hne",
    "ho",
    "hr",
    "hrv",
    "hrx",
    "hsb",
    "ht",
    "hu",
    "hun",
    "hup",
    "hus",
    "hy",
    "hye",
    "hz",
    "ia",
    "iba",
    "ibo",
    "ice",
    "id",
    "ido",
    "ie",
    "ig",
    "ii",
    "iii",
    "ik",
    "iku",
    "ile",
    "ilo",
    "in",
    "in_id",
    "ina",
    "ind",
    "inh",
    "io",
    "ipk",
    "is",
    "isl",
    "it",
    "it_ch",
    "ita",
    "its",
    "iu",
    "iw",
    "iw_il",
    "ja",
    "ja_ja",
    "ja_ks",
    "jam",
    "jav",
    "jbo",
    "jgo",
    "ji",
    "jmc",
    "jp",
    "jpn",
    "jpr",
    "jrb",
    "jv",
    "jw",
    "ka",
    "kaa",
    "kab",
    "kac",
    "kaj",
    "kal",
    "kam",
    "kan",
    "kas",
    "kat",
    "kau",
    "kaw",
    "kaz",
    "kbd",
    "kcg",
    "kde",
    "kea",
    "kg",
    "kha",
    "khm",
    "kho",
    "ki",
    "kik",
    "kin",
    "kir",
    "kj",
    "kk",
    "kk@latin",
    "kk_cyrl",
    "kk_latn",
    "kkj",
    "kl",
    "km",
    "kmb",
    "kmr",
    "kmr_latn",
    "kn",
    "ko",
    "ko_ko",
    "kok",
    "kom",
    "kon",
    "kor",
    "kos",
    "kpe",
    "kr",
    "krc",
    "krl",
    "kru",
    "ks",
    "ksb",
    "ksh",
    "ku",
    "ku_iq",
    "kua",
    "kum",
    "kur",
    "kut",
    "kv",
    "kw",
    "ky",
    "kz",
    "la",
    "lad",
    "lag",
    "lah",
    "lam",
    "lao",
    "lat",
    "lav",
    "lb",
    "lez",
    "lg",
    "li",
    "lim",
    "lin",
    "lit",
    "lk",
    "lki",
    "lkt",
    "ln",
    "lo",
    "lol",
    "loz",
    "lt",
    "ltg",
    "ltz",
    "lu",
    "lua",
    "lub",
    "lug",
    "lui",
    "lun",
    "luo",
    "lus",
    "lv",
    "mac",
    "mad",
    "mag",
    "mah",
    "mai",
    "mak",
    "mal",
    "man",
    "mao",
    "mar",
    "mas",
    "may",
    "mdf",
    "mdr",
    "me",
    "men",
    "mfe",
    "mg",
    "mga",
    "mgo",
    "mh",
    "mhr",
    "mi",
    "mia",
    "mic",
    "min",
    "mjw",
    "mk",
    "mkd",
    "ml",
    "mlg",
    "mlt",
    "mn",
    "mnc",
    "mni",
    "mnk",
    "mnw",
    "mo",
    "moh",
    "mon",
    "mos",
    "mr",
    "mri",
    "ms",
    "ms_arab",
    "msa",
    "mt",
    "mus",
    "mwl",
    "mwr",
    "my",
    "mya",
    "myv",
    "na",
    "nah",
    "nan",
    "nap",
    "naq",
    "nau",
    "nav",
    "nb",
    "nb_no",
    "nbl",
    "nd",
    "nde",
    "ndo",
    "nds",
    "ne",
    "nep",
    "new",
    "ng",
    "nia",
    "niu",
    "nl",
    "nl_be",
    "nlb",
    "nld",
    "nn",
    "nnh",
    "nno",
    "no",
    "no_nb",
    "no_no",
    "nob",
    "nog",
    "non",
    "nor",
    "norwegian",
    "np",
    "nqo",
    "nr",
    "nso",
    "nv",
    "nwc",
    "ny",
    "nya",
    "nym",
    "nyn",
    "nyo",
    "nzi",
    "oc",
    "oci",
    "oj",
    "oji",
    "om",
    "or",
    "ori",
    "orm",
    "os",
    "osa",
    "oss",
    "ota",
    "otk",
    "pa",
    "pa_pk",
    "pag",
    "pal",
    "pam",
    "pan",
    "pap",
    "pau",
    "peo",
    "per",
    "phn",
    "pi",
    "pk",
    "pl",
    "pli",
    "plk",
    "pms",
    "pol",
    "pon",
    "por",
    "portuguese_br",
    "portuguese_portugal",
    "pr",
    "prg",
    "pro",
    "ps",
    "pt",
    "pt_ao",
    "pt_br",
    "pt_pt",
    "ptb",
    "ptg",
    "pu",
    "pus",
    "qu",
    "qu_ec",
    "quc",
    "que",
    "raj",
    "rap",
    "rar",
    "rcf",
    "rm",
    "rn",
    "ro",
    "ro_md",
    "rof",
    "roh",
    "rom",
    "ron",
    "rs",
    "ru",
    "ru_r",
    "ru_rr",
    "ru_ua",
    "rue",
    "rum",
    "run",
    "rup",
    "rus",
    "rw",
    "rwk",
    "sa",
    "sad",
    "sag",
    "sah",
    "sai",
    "sam",
    "san",
    "saq",
    "sas",
    "sat",
    "sc",
    "scc",
    "schinese",
    "scn",
    "sco",
    "scr",
    "sd",
    "sdh",
    "se",
    "seh",
    "sel",
    "serbo_croatian",
    "ses",
    "sg",
    "sga",
    "sgn",
    "sh",
    "shi",
    "shn",
    "si",
    "sid",
    "sin",
    "sk",
    "sky",
    "sl",
    "sl_sl",
    "slk",
    "slo",
    "slv",
    "sm",
    "sma",
    "sme",
    "smi",
    "smj",
    "sml",
    "smn",
    "smo",
    "sms",
    "sn",
    "sna",
    "snd",
    "snk",
    "so",
    "sog",
    "som",
    "son",
    "sot",
    "source",
    "spa",
    "sq",
    "sqi",
    "sr",
    "sr@cyrillic",
    "sr@ije",
    "sr@ijekavian",
    "sr@ijekavian_latn",
    "sr@ijekavianlatin",
    "sr@latin",
    "sr_cs",
    "sr_cyrl",
    "sr_cyrl_rs",
    "sr_latn",
    "sr_latn_rs",
    "sr_me",
    "sr_rs@cyrillic",
    "sr_rs@latin",
    "srb",
    "srd",
    "srl",
    "srn",
    "srp",
    "srr",
    "ss",
    "ssw",
    "ssy",
    "st",
    "su",
    "suk",
    "sun",
    "sus",
    "sux",
    "sv",
    "sve",
    "svk",
    "sw",
    "sw_cd",
    "sw_tz",
    "swa",
    "swe",
    "syc",
    "syr",
    "szl",
    "ta",
    "ta_lk",
    "tah",
    "tam",
    "tat",
    "tchinese",
    "te",
    "tel",
    "tem",
    "teo",
    "ter",
    "tet",
    "tg",
    "tgk",
    "tgl",
    "th",
    "tha",
    "ti",
    "tib",
    "tig",
    "tir",
    "tiv",
    "tk",
    "tkl",
    "tl",
    "tlh",
    "tlh-qaak",
    "tli",
    "tmh",
    "tn",
    "to",
    "tog",
    "ton",
    "tpi",
    "tr",
    "trk",
    "trv",
    "ts",
    "tsi",
    "tsj",
    "tsn",
    "tso",
    "tt",
    "tt@iqtelif",
    "tuk",
    "tum",
    "tur",
    "tvl",
    "tw",
    "twi",
    "ty",
    "tyv",
    "tzj",
    "tzm",
    "ua",
    "udm",
    "ug",
    "uga",
    "uig",
    "uk",
    "ukr",
    "umb",
    "und",
    "ur",
    "ur_in",
    "ur_pk",
    "urd",
    "us",
    "uz",
    "uz@cyrillic",
    "uz@latin",
    "uz@latn",
    "uz_latn",
    "uzb",
    "vai",
    "val_es",
    "ve",
    "vec",
    "ven",
    "vi",
    "vie",
    "vls",
    "vn",
    "vo",
    "vol",
    "vot",
    "vun",
    "wa",
    "wae",
    "wal",
    "war",
    "was",
    "wel",
    "wen",
    "wln",
    "wo",
    "wol",
    "xal",
    "xbelorussian",
    "xh",
    "xho",
    "xog",
    "yao",
    "yap",
    "yi",
    "yid",
    "yo",
    "yor",
    "yue",
    "za",
    "zap",
    "zbl",
    "zen",
    "zgh",
    "zh",
    "zh_chs",
    "zh_cmn_hans",
    "zh_cmn_hant",
    "zh_cn",
    "zh_hans",
    "zh_hans_cn",
    "zh_hans_sg",
    "zh_hant",
    "zh_hant@zh",
    "zh_hant_hk",
    "zh_hant_tw",
    "zh_hk",
    "zh_latn",
    "zh_latn@pinyin",
    "zh_latn_pinyin",
    "zh_sg",
    "zh_tw",
    "zha",
    "zhcn",
    "zho",
    "zhtw",
    "zu",
    "zul",
    "zun",
    "zza",
}



#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

"""Language data definitions.

This is an automatically generated file, see scripts/generate-language-data

Do not edit, please adjust language definitions in following repository:
https://github.com/WeblateOrg/language-data
"""
# pylint: disable=line-too-long,too-many-lines


# Language aliases
ALIASES = {
    "braz_por": "pt_BR",
    "chinese": "zh_Hans",
    "chinese_chs": "zh_Hans",
    "schinese": "zh_Hans",
    "chinese_zh": "zh_Hans",
    "tchinese": "zh_Hant",
    "dutch_be": "nl_BE",
    "flemish": "nl_BE",
    "english_uk": "en_GB",
    "portuguese_br": "pt_BR",
    "portuguese_portugal": "pt_PT",
    "serbo_croatian": "sr_Latn",
    "norwegian": "nb_NO",
    "xbelorussian": "be",
    "be_rby": "be_Latn",
    "val_es": "ca@valencia",
    "no_nb": "nb_NO",
    "no_no": "nb_NO",
    "es_eu": "eu",
    "ru_r": "ru",
    "ru_rr": "ru",
    "ar_ar": "ar",
    "jp": "ja",
    "ba_ck": "ba",
    "ca_ps": "ca",
    "by": "be",
    "ua": "uk",
    "en_en": "en",
    "cn": "zh_Hans",
    "sl_sl": "sl",
    "pu": "pa",
    "ja_ja": "ja",
    "ko_ko": "ko",
    "in": "id",
    "iw": "he",
    "iw_il": "he",
    "in_id": "id",
    "ji": "yi",
    "jw": "jv",
    "mo": "ro_MD",
    "scc": "sr",
    "scr": "hr",
    "sh": "sr_Latn",
    "no": "nb_NO",
    "np": "ne",
    "pk": "ur_PK",
    "sr_cs": "sr",
    "sr_me": "me",
    "sr_latn_rs": "sr_Latn",
    "sr_cyrl_rs": "sr_Cyrl",
    "bs_latn_ba": "bs_Latn",
    "nb": "nb_NO",
    "be@latin": "be_Latn",
    "sr@latin": "sr_Latn",
    "sr_rs@latin": "sr_Latn",
    "sr@cyrillic": "sr_Cyrl",
    "sr_rs@cyrillic": "sr_Cyrl",
    "uz@latin": "uz_Latn",
    "uz@latn": "uz_Latn",
    "uz@cyrillic": "uz",
    "zh": "zh_Hans",
    "zhcn": "zh_Hans",
    "zh_cn": "zh_Hans",
    "zh_chs": "zh_Hans",
    "zh_sg": "zh_Hans_SG",
    "zhtw": "zh_Hant",
    "zh_tw": "zh_Hant",
    "zh_hant_tw": "zh_Hant",
    "zh_hant@zh": "zh_Hant",
    "cmn": "zh_Hans",
    "zh_hk": "zh_Hant_HK",
    "zh_hans_cn": "zh_Hans",
    "zh_cmn_hans": "zh_Hans",
    "zh_cmn_hant": "zh_Hant",
    "zh_latn_pinyin": "zh_Latn",
    "zh_latn@pinyin": "zh_Latn",
    "ku_iq": "kmr",
    "az_ir": "azb",
    "ary": "ar_MA",
    "kk@latin": "kk_Latn",
    "kk_cyrl": "kk",
    "sr@ije": "sr@ijekavian",
    "sr@ijekavianlatin": "sr@ijekavian_Latn",
    "base": "en",
    "source": "en",
    "de_fo": "de@formal",
    "de_form": "de@formal",
    "de_de_x_formal": "de@formal",
    "de_de_x_informal": "de@informal",
    "fr_fo": "fr@formal",
    "fr_form": "fr@formal",
    "fr_fr_x_formal": "fr@formal",
    "fr_fr_x_informal": "fr@informal",
    "dk": "da",
    "gr": "el",
    "rs": "sr",
    "kz": "kk",
    "lk": "si",
    "us": "en_US",
    "vn": "vi",
    "bd": "bn",
    "eg": "ar_EG",
    "ca_es@valencia": "ca@valencia",
    "ca_xv": "ca@valencia",
    "ca_valencia": "ca@valencia",
    "ang@latin": "ang",
    "cz": "cs",
    "svk": "sk",
    "ptb": "pt_PR",
    "enu": "en_US",
    "bgr": "bg",
    "ptg": "pt",
    "esp": "es",
    "cht": "zh_Hant",
    "chs": "zh_Hans",
    "sve": "sv",
    "csy": "cs",
    "plk": "pl",
    "trk": "tr",
    "des": "de_CH",
    "ena": "en_AU",
    "enp": "en",
    "frb": "fr_BE",
    "frc": "fr_CA",
    "gae": "gd",
    "its": "it_CH",
    "nlb": "nl_BE",
    "sky": "sk",
    "srl": "sr_Latn",
    "srb": "sr_Cyrl",
    "aar": "aa",
    "abk": "ab",
    "afr": "af",
    "aka": "ak",
    "alb": "sq",
    "amh": "am",
    "ara": "ar",
    "arg": "an",
    "arm": "hy",
    "asm": "as",
    "ava": "av",
    "ave": "ae",
    "aym": "ay",
    "aze": "az",
    "bak": "ba",
    "bam": "bm",
    "baq": "eu",
    "bel": "be",
    "ben": "bn",
    "bih": "bh",
    "bis": "bi",
    "bod": "bo",
    "bos": "bs",
    "bre": "br",
    "bul": "bg",
    "bur": "my",
    "cat": "ca",
    "ces": "cs",
    "cha": "ch",
    "che": "ce",
    "chi": "zh",
    "chu": "cu",
    "chv": "cv",
    "cor": "kw",
    "cos": "co",
    "cre": "cr",
    "cym": "cy",
    "cze": "cs",
    "dan": "da",
    "deu": "de",
    "div": "dv",
    "dut": "nl",
    "dzo": "dz",
    "ell": "el",
    "eng": "en",
    "epo": "eo",
    "est": "et",
    "eus": "eu",
    "ewe": "ee",
    "fao": "fo",
    "fas": "fa",
    "fij": "fj",
    "fin": "fi",
    "fra": "fr",
    "fre": "fr",
    "fry": "fy",
    "ful": "ff",
    "geo": "ka",
    "ger": "de",
    "gla": "gd",
    "gle": "ga",
    "glg": "gl",
    "glv": "gv",
    "gre": "el",
    "grn": "gn",
    "guj": "gu",
    "hat": "ht",
    "hau": "ha",
    "hbs": "sh",
    "heb": "he",
    "her": "hz",
    "hin": "hi",
    "hmo": "ho",
    "hrv": "hr",
    "hun": "hu",
    "hye": "hy",
    "ibo": "ig",
    "ice": "is",
    "ido": "io",
    "iii": "ii",
    "iku": "iu",
    "ile": "ie",
    "ina": "ia",
    "ind": "id",
    "ipk": "ik",
    "isl": "is",
    "ita": "it",
    "jav": "jv",
    "jpn": "ja",
    "kal": "kl",
    "kan": "kn",
    "kas": "ks",
    "kat": "ka",
    "kau": "kr",
    "kaz": "kk",
    "khm": "km",
    "kik": "ki",
    "kin": "rw",
    "kir": "ky",
    "kom": "kv",
    "kon": "kg",
    "kor": "ko",
    "kua": "kj",
    "kur": "ku",
    "lao": "lo",
    "lat": "la",
    "lav": "lv",
    "lim": "li",
    "lin": "ln",
    "lit": "lt",
    "ltz": "lb",
    "lub": "lu",
    "lug": "lg",
    "mac": "mk",
    "mah": "mh",
    "mal": "ml",
    "mao": "mi",
    "mar": "mr",
    "may": "ms",
    "mkd": "mk",
    "mlg": "mg",
    "mlt": "mt",
    "mon": "mn",
    "mri": "mi",
    "msa": "ms",
    "mya": "my",
    "nau": "na",
    "nav": "nv",
    "nbl": "nr",
    "nde": "nd",
    "ndo": "ng",
    "nep": "ne",
    "nld": "nl",
    "nno": "nn",
    "nob": "nb",
    "nor": "no",
    "nya": "ny",
    "oci": "oc",
    "oji": "oj",
    "ori": "or",
    "orm": "om",
    "oss": "os",
    "pan": "pa",
    "per": "fa",
    "pli": "pi",
    "pol": "pl",
    "por": "pt",
    "pus": "ps",
    "que": "qu",
    "roh": "rm",
    "ron": "ro",
    "rum": "ro",
    "run": "rn",
    "rus": "ru",
    "sag": "sg",
    "san": "sa",
    "sin": "si",
    "slk": "sk",
    "slo": "sk",
    "slv": "sl",
    "sme": "se",
    "smo": "sm",
    "sna": "sn",
    "snd": "sd",
    "som": "so",
    "sot": "st",
    "spa": "es",
    "sqi": "sq",
    "srd": "sc",
    "srp": "sr",
    "ssw": "ss",
    "sun": "su",
    "swa": "sw",
    "swe": "sv",
    "tah": "ty",
    "tam": "ta",
    "tat": "tt",
    "tel": "te",
    "tgk": "tg",
    "tgl": "tl",
    "tha": "th",
    "tib": "bo",
    "tir": "ti",
    "ton": "to",
    "tsn": "tn",
    "tso": "ts",
    "tuk": "tk",
    "tur": "tr",
    "twi": "tw",
    "uig": "ug",
    "ukr": "uk",
    "urd": "ur",
    "uzb": "uz",
    "ven": "ve",
    "vie": "vi",
    "vol": "vo",
    "wel": "cy",
    "wln": "wa",
    "wol": "wo",
    "xho": "xh",
    "yid": "yi",
    "yor": "yo",
    "zha": "za",
    "zho": "zh_Hant",
    "zul": "zu",
}



#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

# List of RTL languages
RTL_LANGS = {
    "ar",
    "ara",
    "arc",
    "ae",
    "aii",
    "ave",
    "ckb",
    "dv",
    "egy",
    "fa",
    "fas",
    "ha",
    "he",
    "heb",
    "khw",
    "ks",
    "ms_Arab",
    "nqo",
    "pal",
    "per",
    "phn",
    "ps",
    "sam",
    "syc",
    "syr",
    "ug",
    "ur",
    "urd",
    "yi",
}



#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

"""Language data definitions.

This is an automatically generated file, see scripts/generate-language-data

Do not edit, please adjust language definitions in following repository:
https://github.com/WeblateOrg/language-data
"""
# pylint: disable=line-too-long,too-many-lines


# Known country codes
COUNTRIES = {
    "abw",
    "ad",
    "ae",
    "af",
    "afg",
    "ag",
    "ago",
    "ai",
    "aia",
    "al",
    "ala",
    "alb",
    "am",
    "and",
    "ao",
    "aq",
    "ar",
    "are",
    "arg",
    "arm",
    "as",
    "asm",
    "at",
    "ata",
    "atf",
    "atg",
    "au",
    "aus",
    "aut",
    "aw",
    "ax",
    "az",
    "aze",
    "ba",
    "bb",
    "bd",
    "bdi",
    "be",
    "bel",
    "ben",
    "bes",
    "bf",
    "bfa",
    "bg",
    "bgd",
    "bgr",
    "bh",
    "bhr",
    "bhs",
    "bi",
    "bih",
    "bj",
    "bl",
    "blm",
    "blr",
    "blz",
    "bm",
    "bmu",
    "bn",
    "bo",
    "bol",
    "bq",
    "br",
    "bra",
    "brb",
    "brn",
    "bs",
    "bt",
    "btn",
    "bv",
    "bvt",
    "bw",
    "bwa",
    "by",
    "bz",
    "ca",
    "caf",
    "can",
    "cc",
    "cck",
    "cd",
    "cf",
    "cg",
    "ch",
    "che",
    "chl",
    "chn",
    "ci",
    "civ",
    "ck",
    "cl",
    "cm",
    "cmr",
    "cn",
    "co",
    "cod",
    "cog",
    "cok",
    "col",
    "com",
    "cpv",
    "cr",
    "cri",
    "cu",
    "cub",
    "cuw",
    "cv",
    "cw",
    "cx",
    "cxr",
    "cy",
    "cym",
    "cyp",
    "cz",
    "cze",
    "de",
    "deu",
    "dj",
    "dji",
    "dk",
    "dm",
    "dma",
    "dnk",
    "do",
    "dom",
    "dz",
    "dza",
    "ec",
    "ecu",
    "ee",
    "eg",
    "egy",
    "eh",
    "er",
    "eri",
    "es",
    "esh",
    "esp",
    "est",
    "et",
    "eth",
    "fi",
    "fin",
    "fj",
    "fji",
    "fk",
    "flk",
    "fm",
    "fo",
    "fr",
    "fra",
    "fro",
    "fsm",
    "ga",
    "gab",
    "gb",
    "gbr",
    "gd",
    "ge",
    "geo",
    "gf",
    "gg",
    "ggy",
    "gh",
    "gha",
    "gi",
    "gib",
    "gin",
    "gl",
    "glp",
    "gm",
    "gmb",
    "gn",
    "gnb",
    "gnq",
    "gp",
    "gq",
    "gr",
    "grc",
    "grd",
    "grl",
    "gs",
    "gt",
    "gtm",
    "gu",
    "guf",
    "gum",
    "guy",
    "gw",
    "gy",
    "hk",
    "hkg",
    "hm",
    "hmd",
    "hn",
    "hnd",
    "hr",
    "hrv",
    "ht",
    "hti",
    "hu",
    "hun",
    "id",
    "idn",
    "ie",
    "il",
    "im",
    "imn",
    "in",
    "ind",
    "io",
    "iot",
    "iq",
    "ir",
    "irl",
    "irn",
    "irq",
    "is",
    "isl",
    "isr",
    "it",
    "ita",
    "jam",
    "je",
    "jey",
    "jm",
    "jo",
    "jor",
    "jp",
    "jpn",
    "kaz",
    "ke",
    "ken",
    "kg",
    "kgz",
    "kh",
    "khm",
    "ki",
    "kir",
    "km",
    "kn",
    "kna",
    "kor",
    "kp",
    "kr",
    "kw",
    "kwt",
    "ky",
    "kz",
    "la",
    "lao",
    "lb",
    "lbn",
    "lbr",
    "lby",
    "lc",
    "lca",
    "li",
    "lie",
    "lk",
    "lka",
    "lr",
    "ls",
    "lso",
    "lt",
    "ltu",
    "lu",
    "lux",
    "lv",
    "lva",
    "ly",
    "ma",
    "mac",
    "maf",
    "mar",
    "mc",
    "mco",
    "md",
    "mda",
    "mdg",
    "mdv",
    "me",
    "mex",
    "mf",
    "mg",
    "mh",
    "mhl",
    "mk",
    "mkd",
    "ml",
    "mli",
    "mlt",
    "mm",
    "mmr",
    "mn",
    "mne",
    "mng",
    "mnp",
    "mo",
    "moz",
    "mp",
    "mq",
    "mr",
    "mrt",
    "ms",
    "msr",
    "mt",
    "mtq",
    "mu",
    "mus",
    "mv",
    "mw",
    "mwi",
    "mx",
    "my",
    "mys",
    "myt",
    "mz",
    "na",
    "nam",
    "nc",
    "ncl",
    "ne",
    "ner",
    "nf",
    "nfk",
    "ng",
    "nga",
    "ni",
    "nic",
    "niu",
    "nl",
    "nld",
    "no",
    "nor",
    "np",
    "npl",
    "nr",
    "nru",
    "nu",
    "nz",
    "nzl",
    "om",
    "omn",
    "pa",
    "pak",
    "pan",
    "pcn",
    "pe",
    "per",
    "pf",
    "pg",
    "ph",
    "phl",
    "pk",
    "pl",
    "plw",
    "pm",
    "pn",
    "png",
    "pol",
    "pr",
    "pri",
    "prk",
    "prt",
    "pry",
    "ps",
    "pse",
    "pt",
    "pw",
    "py",
    "pyf",
    "qa",
    "qat",
    "re",
    "reu",
    "ro",
    "rou",
    "rs",
    "ru",
    "rus",
    "rw",
    "rwa",
    "sa",
    "sau",
    "sb",
    "sc",
    "sd",
    "sdn",
    "se",
    "sen",
    "sg",
    "sgp",
    "sgs",
    "sh",
    "shn",
    "si",
    "sj",
    "sjm",
    "sk",
    "sl",
    "slb",
    "sle",
    "slv",
    "sm",
    "smr",
    "sn",
    "so",
    "som",
    "spm",
    "sr",
    "srb",
    "ss",
    "ssd",
    "st",
    "stp",
    "sur",
    "sv",
    "svk",
    "svn",
    "swe",
    "swz",
    "sx",
    "sxm",
    "sy",
    "syc",
    "syr",
    "sz",
    "tc",
    "tca",
    "tcd",
    "td",
    "tf",
    "tg",
    "tgo",
    "th",
    "tha",
    "tj",
    "tjk",
    "tk",
    "tkl",
    "tkm",
    "tl",
    "tls",
    "tm",
    "tn",
    "to",
    "ton",
    "tr",
    "tt",
    "tto",
    "tun",
    "tur",
    "tuv",
    "tv",
    "tw",
    "twn",
    "tz",
    "tza",
    "ua",
    "ug",
    "uga",
    "ukr",
    "um",
    "umi",
    "ury",
    "us",
    "usa",
    "uy",
    "uz",
    "uzb",
    "va",
    "vat",
    "vc",
    "vct",
    "ve",
    "ven",
    "vg",
    "vgb",
    "vi",
    "vir",
    "vn",
    "vnm",
    "vu",
    "vut",
    "wf",
    "wlf",
    "ws",
    "wsm",
    "ye",
    "yem",
    "yt",
    "za",
    "zaf",
    "zm",
    "zmb",
    "zw",
    "zwe",
}



#!/usr/bin/env python3
#
# Copyright © 2012 - 2021 Michal Čihař <michal@cihar.com>
#
# This file is part of Weblate <https://weblate.org/>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

import os
from distutils.command.build import build
from distutils.core import Command
from distutils.dep_util import newer
from glob import glob
from itertools import chain

from setuptools import setup
from translate.tools.pocompile import convertmo

LOCALE_MASKS = [
    "weblate_language_data/locale/*/LC_MESSAGES/*.po",
]


class BuildMo(Command):
    description = "update MO files to match PO"
    user_options = []

    def initialize_options(self):
        self.build_base = None

    def finalize_options(self):
        self.set_undefined_options("build", ("build_base", "build_base"))

    def run(self):
        for name in chain.from_iterable(glob(mask) for mask in LOCALE_MASKS):
            output = os.path.splitext(name)[0] + ".mo"
            if not newer(name, output):
                continue
            print(f"compiling {name} -> {output}")
            with open(name, "rb") as pofile, open(output, "wb") as mofile:
                convertmo(pofile, mofile, None)


class WeblateBuild(build):
    """Override the default build with new subcommands."""

    # The build_mo has to be before build_data
    sub_commands = [("build_mo", lambda self: True)] + build.sub_commands


setup(
    cmdclass={"build_mo": BuildMo, "build": WeblateBuild},
)
